function [min_d,min_t] = UTM_2conflict(flights,lanes,f1,f2,f1i,f2i,...
    cur_time)
% UTM_2conflict - find conflicting flights
% On input:
%     flights (flight struct): flight info
%     lanes (nx6): lane entry/exit 3D points
%     f1 (int): flight 1 id
%     f2 (int): flight 2 id
%     f1i (int): traj 1 index
%     f2i (int): traj 2 index
%     cur_time (float): current time
% Call:
%     [md,mt] = TM_2conflict(flights,lanes,1,3,21,34,12.45);
% Author:
%     T. Henderson
%     UU
%     Summer 2020
%

f1_lane = flights(f1).traj(f1i);
P1 = lanes(f1_lane,1:3);
P2 = lanes(f1_lane,4:6);
dirP = P2 - P1;
dirP = dirP/norm(dirP);
f1_speed = flights(f1).lane_speeds(f1i);
f1_dist = flights(f1).lane_dists(f1i);
O1= P1 + dirP*f1_dist;
V1 = f1_speed*dirP;
f1_TOD = flights(f1).TOD(f1i);
f1_TOA = flights(f1).TOA(f1i);

f2_lane = flights(f2).traj(f2i);
Q1 = lanes(f2_lane,1:3);
Q2 = lanes(f2_lane,4:6);
dirQ = Q2 - Q1;
dirQ = dirQ/norm(dirQ);
f2_speed = flights(f2).lane_speeds(f2i);
f2_dist = flights(f2).lane_dists(f2i);
O2 = Q1 + dirQ*f2_dist;
V2 = f2_speed*dirQ;
f2_TOD = flights(f2).TOD(f2i);
f2_TOA = flights(f2).TOA(f2i);
ts1 = cur_time;
te1 = min(f1_TOA,f2_TOA);
ts2 = ts1;
te2 = te1;
[min_d,min_t] = UTM_trajMinDist(O1,V1,ts1,te1,O2,V2,ts2,te2);
tch = 0;
