function  [flights,slowed] = UTM_deconflict_pair(flights_in,f1,f2,f1i,...
    f2i,lanes,cur_time)
% UTM_deconflict_pair - deconflict pair of flights
% On input:
%     flights_in (flights struct): flight info
%     f1 (int): flight 1 id
%     f2 (int): flight 2 id
%     f1i (int): traj 1 index
%     f2i (int): traj 2 index
%     lanes (nx6 array): lan entry/exit 3D points
%     cur_time (float): current time
% On output:
%     flights (flight struct): updated flights
%     slowed (1xk vector): id's of slowed flights
% Call:
%     [flights,sl] = UTM_deconflict_pair(flights, 3,5,12,52,lanes,45.32);
% Author:
%     T. Henderson
%     UU
%     Summer 2020
%

UTM_load_vars;

slowed = 0;
flights = flights_in;

f1_lane = flights(f1).traj(f1i);
f1_lane_len = flights(f1).lane_lengths(f1i);
f1_num_lanes = length(flights(f1).traj);
P1 = lanes(f1_lane,1:3);
P2 = lanes(f1_lane,4:6);
dirP = P2 - P1;
dirP = dirP/norm(dirP);
speed1 = flights(f1).lane_speeds(f1i);
dist1 = flights(f1).lane_dists(f1i);
O1 = P1 + dist1*dirP;
V1 = speed1*dirP;
TOD1 = flights(f1).TOD(f1i);
TOA1 = flights(f1).TOA(f1i);
ts1 = cur_time;

f2_lane = flights(f2).traj(f2i);
f2_lane_len = flights(f2).lane_lengths(f2i);
f2_num_lanes = length(flights(f2).traj);
Q1 = lanes(f2_lane,1:3);
Q2 = lanes(f2_lane,4:6);
dirQ = Q2 - Q1;
dirQ = dirQ/norm(dirQ);
speed2 = flights(f2).lane_speeds(f2i);
dist2 = flights(f2).lane_dists(f2i);
O2 = Q1 + dist2*dirQ;
V2 = speed2*dirQ;
TOA2 = flights(f2).TOA(f2i);
ts2 = cur_time;

te1 = min(TOA1,TOA2);
te2 = te1;

% try to slow flight f1
done = 0;
while done==0
    [min_d,min_t] = UTM_trajMinDist(O1,V1,ts1,te1,O2,V2,ts2,te2);
    if min_d<d_S  % conflict
        speed1 = max(0,speed1 - SLOW_BY);
        slowed = 1;
        if speed1<=0
            done = 1;
        else
            V1 = speed1*dirP;
            TOA1 = cur_time + (f1_lane_len-dist1)/speed1;
            te1 = min(TOA1,TOA2);
            te2 = te1;
        end
    else
        done = 1;
    end
end

if speed1>ZERO_THRESH    % Flight f1 slows and is solution
    flights(f1).lane_speeds(f1i) = speed1;
    flights(f1).TOA(f1i) = TOA1;
    for k = f1i+1:f1_num_lanes
        flights(f1).TOD(k) = flights(f1).TOA(k-1);
        flights(f1).TOA(k) = flights(f1).TOD(k)...
            + flights(f1).lane_lengths(k)/flights(f1).lane_speeds(k);
    end
    return
end

speed1 = flights(f1).lane_speeds(f1i);
V1 = speed1*dirP;
TOA1 = cur_time + (f1_lane_len-dist1)/speed1;
te1 = min(TOA1,TOA2);
te2 = te1;

% try to slow flight f2
done = 0;
while done==0
    [min_d,min_t] = UTM_trajMinDist(O1,V1,ts1,te1,O2,V2,ts2,te2);
    if min_d<d_S  % conflict
        speed2 = max(0,speed2 - SLOW_BY);
        slowed = 1;
        if speed2<=0
            done = 1;
        else
            V2 = speed2*dirQ;
            TOA2 = cur_time + (f2_lane_len-dist2)/speed2;
            te1 = min(TOA1,TOA2);
            te2 = te1;
        end
    else
        done = 1;
    end
end

if speed2>ZERO_THRESH    % Flight f2 slows and is solution
    flights(f2).lane_speeds(f2i) = speed2;
    flights(f2).TOA(f2i) = TOA2;
    for k = f2i+1:f2_num_lanes
        flights(f2).TOD(k) = flights(f2).TOA(k-1);
        flights(f2).TOA(k) = flights(f2).TOD(k)...
            + flights(f2).lane_lengths(k)/flights(f2).lane_speeds(k);
    end
    return
end

if flights(f1).total_dist<=flights(f2).total_dist
    flights(f1).status = DONE;
else
    flights(f2).status = DONE;
end
