function [TOD,TOA] = UTM_set_TOD_TOA(start_time,lane_speeds,lane_lengths)
% UTM_set_TOD_TOA - set TOD and TOA given start time
% On input:
%     start_time (float): start time for flight
%     lane_speeds (1xn vector): speed in each lane
%     lane_lengths (1xn vector): length of each lane
% On output:
%     TOD (1xn vector): Time of Departure from entry point in each lane
%     TOA (1xn vector): Time of Arrival at exit point of each lane
% Call:
%     [TOD,TOA] = UTM_set_TOD_TOA(2.3,speeds,lengths);
% Author:
%     T. Henderson
%     UU
%     Summer 2020
%

num_lanes = length(lane_speeds);
TOD = zeros(1,num_lanes);
TOA = zeros(1,num_lanes);
TOD(1) = start_time;
TOA(1) = start_time + lane_lengths(1)/lane_speeds(1);
for e = 2:num_lanes
    TOD(e) = TOA(e-1);
    TOA(e) = TOD(e) + lane_lengths(e)/lane_speeds(e);
end
